#!/bin/bash

echo "PWD=${PWD}"
if [ -d "${PWD}/deploy" ]; then
  SCRIPT_DIR="${PWD}/deploy"
else
  SCRIPT_DIR="${PWD}"
fi

: "${PORT:=8880}"
: "${CONTROL_PORT:=8881}"


echo "DEPLOYMENT_PROVIDER=$DEPLOYMENT_PROVIDER"


echo "======================================================================"
echo "Fast-cube-engine $ROLLBAR_ENV superxformgcp server.sh starting..."

export TZ=UTC
export JAVA_OOM_OPTS="-XX:+ExitOnOutOfMemoryError -XX:+CrashOnOutOfMemoryError"
export JAVA_GC_ARGS="-XX:+UseG1GC -XX:InitiatingHeapOccupancyPercent=35 -Xlog:gc*=warning"
export JAVA_BASE_ARGS="$JAVA_OPTS $JAVA_OOM_OPTS $JAVA_MEMORY_ARGS -Xmx$JAVA_HEAP_MAX -Xms$JAVA_HEAP_MIN $JAVA_GC_ARGS -XshowSettings:vm"
echo "JAVA_OPTS=$JAVA_OPTS"
echo "JAVA_HEAP_MIN=$JAVA_HEAP_MIN"
echo "JAVA_HEAP_MAX=$JAVA_HEAP_MAX"
echo "JAVA_MEMORY_ARGS=$JAVA_MEMORY_ARGS"
echo "THREAD_POOL=$THREAD_POOL"
echo "BATCH_LOG=$BATCH_LOG"

JMX_ARGS="-Dcom.sun.management.jmxremote \
-Dcom.sun.management.jmxremote.authenticate=false \
-Dcom.sun.management.jmxremote.ssl=false \
-Dcom.sun.management.jmxremote.local.only=false \
-Dcom.sun.management.jmxremote.port=1099 \
-Dcom.sun.management.jmxremote.rmi.port=1099 \
-Djava.rmi.server.hostname=127.0.0.1 "

LOG_CONF="config/log4j2.xml"

export SPARK_OPTS="-Dlog4j2.configurationFile=$LOG_CONF -Dspark.executor.memoryOverhead=$SPARK_EXECUTOR_MEM \
-DDEPLOYMENT_PROVIDER=$DEPLOYMENT_PROVIDER \
-Dspark.driver.memory=$SPARK_DRIVER_MEM -Dspark.driver.memoryOverhead=$SPARK_MEM_OVERHEAD -Dspark.driver.maxResultSize=$SPARK_MAX_RESULT_SIZE \
-Dspark.rdd.compress=true -Dlog4j.debug=true -Dspark.memory.fraction=0.8 -Dspark.memory.storageFraction=0.3 -Dspark.network.timeout=400 \
-Dspark.dynamicAllocation.enabled=false -Dspark.scheduler.barrier.maxConcurrentTasksCheck.maxFailuresMaximum=5"

echo $SPARK_OPTS

TMP_DIR=/tmp

# RabbitMQ:
# in production and staging, we would use RABBITMQ_USERNAME/PASSWORD injected by
# the secret from the Jenkinsfile.
# for dev, we use the "local" RabbitMQ broker which is a POD co-deployed in your
# NG k8s dev env. Here, the env vars are $NG_RABBITMQ_USERNAME/PASSWORD (note the
# "NG_" prefix).
env | grep RABBIT | grep HOST
RABBIT_HOST_PARAM="${NG_RABBITMQ_SERVICE_HOST}:${NG_RABBITMQ_SERVICE_PORT}"
echo "Using rabbit host=$RABBIT_HOST_PARAM user=$NG_RABBITMQ_USERNAME"
# Cube Rabbit Host
CUBE_RABBIT_HOST_PARAM="${CUBE_RABBIT_HOST}:${NG_RABBITMQ_SERVICE_PORT}"
echo "Using Cube Rabbit Host=$CUBE_RABBIT_HOST_PARAM"
echo "Using redis=$REDIS_HOST kafka=$KAFKA_HOST"
echo "Using queue=$SUPERSPAXFORM_QUEUE_NAME"
echo 

env | grep REDIS
env | grep KAFKA

if [ "${DEPLOYMENT_PROVIDER}" = "GCP" ] ; then
  # compare with service/charts/values.pr.gcp.yaml
  # DEPLOYMENT_PROVIDER=GCP
  # POD_NAME=use1-preprod-test
  # K8S_CLUSTER=use1.preprod.test.cloudhealthtech.com
  # K8S_NS=vmwcht-fast-cube-engine
  echo "Running in ${K8S_NS}"
  if [[ ${K8S_NS} =~ "-pr-" ]] && [ "x${PR_QUEUE_POSTFIX}" = "x" ]; then
    # PR_QUEUE_POSTFIX=`echo $K8S_NS | egrep -o "\-pr\-[0-9]*"`
    PR_QUEUE_POSTFIX="-pr" # shared queue for all PRs
  fi
  echo "Running in shared gke ${K8S_NS} env in GCP using PR_QUEUE_POSTFIX=$PR_QUEUE_POSTFIX"
fi

echo "superbucket: ${ARTIFACT_LOCATION}"
echo "supergcpbucket: ${SUPER_GCP_BUCKET}"
echo "superazurebucket: ${SUPER_AZURE_BUCKET}"
echo "superalibucket: ${SUPER_ALI_BUCKET}"
echo "outbucket: ${OUTPUT_LOCATION}"
echo "outgcpbucket: ${OUTPUT_GCP_LOCATION}"
echo "outazurebucket: ${OUTPUT_AZURE_LOCATION}"
echo "outalibucket: ${OUTPUT_ALI_LOCATION}"

java $JAVA_BASE_ARGS $SPARK_OPTS \
  -cp "${SCRIPT_DIR}/${JAR_FILENAME}" \
  com.cloudhealthtech.metagen.emr.XFormDriver \
  -db $DB_CREDS \
  -s3 $SVC_AWS_AUTH_MODE \
  -rabbiturl $NG_RABBITMQ_HOST \
  -rabbitpass $NG_RABBITMQ_PASSWORD \
  -rabbituser $NG_RABBITMQ_USERNAME \
  -cuberabbiturl $CUBE_RABBIT_HOST_PARAM \
  -cuberabbitpass $CUBE_RABBIT_PASSWORD \
  -cuberabbituser $CUBE_RABBIT_USERNAME \
  -outloc $OUTPUT_LOCATION \
  -outgcploc $OUTPUT_GCP_LOCATION \
  -outazureloc $OUTPUT_AZURE_LOCATION \
  -outaliloc $OUTPUT_ALI_LOCATION \
  -super $ARTIFACT_LOCATION \
  -supergcp $SUPER_GCP_BUCKET \
  -superazure $SUPER_AZURE_BUCKET \
  -superali $SUPER_ALI_BUCKET \
  -tp $THREAD_POOL \
  -batchlog $BATCH_LOG \
  -tmp $TMP_DIR \
  -cluster "superspaxform" \
  -rbenv $RB_ENV \
  -kafkahost $KAFKA_HOST \
  -uekafkatopic $UE_TOPIC \
  -rabbitemreventkafkatopic $RABBIT_EMR_EVENT_TOPIC \
  -offload superxform_vlc=superspaxform_ds:$CUBE_RABBIT_HOST \
  -vlcJobOffloadThresholdInGB "2"\
  -skipjobtable \
  -qname $SUPERSPAXFORM_QUEUE_NAME$PR_QUEUE_POSTFIX \
  -redis $REDIS_HOST \
  -awskafkahost $AWS_KAFKA_HOST \
  -local